==> mono-2.4.3.tar.bz2: mono-2.4.3/mcs/class/System.Web/System.Web.Configuration_2.0/FormsAuthenticationCredentials.cs <==
//
// System.Web.Configuration.FormsAuthenticationCredentials
//
// Authors:
//	Chris Toshok (toshok@ximian.com)
//
// (C) 2005 Novell, Inc (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System.Configuration;
using System.ComponentModel;

namespace System.Web.Configuration
{
	public sealed class FormsAuthenticationCredentials: ConfigurationElement
	{
		static ConfigurationPropertyCollection properties;
		static ConfigurationProperty passwordFormatProp;
		static ConfigurationProperty usersProp;

		static FormsAuthenticationCredentials ()
		{
			passwordFormatProp = new ConfigurationProperty ("passwordFormat", typeof (FormsAuthPasswordFormat), FormsAuthPasswordFormat.SHA1,
									new GenericEnumConverter (typeof (FormsAuthPasswordFormat)), PropertyHelper.DefaultValidator,
									ConfigurationPropertyOptions.None);
			usersProp = new ConfigurationProperty ("", typeof (FormsAuthenticationUserCollection), null,
							       null, PropertyHelper.DefaultValidator,
							       ConfigurationPropertyOptions.IsDefaultCollection);

			properties = new ConfigurationPropertyCollection ();
			properties.Add (passwordFormatProp);
			properties.Add (usersProp);
		}

		public FormsAuthenticationCredentials ()
		{
		}

		[ConfigurationProperty ("passwordFormat", DefaultValue = "SHA1")]
		public FormsAuthPasswordFormat PasswordFormat {
			get { return (FormsAuthPasswordFormat) base[passwordFormatProp]; }
			set { base[passwordFormatProp] = value; }
		}

		[ConfigurationProperty ("", Options = ConfigurationPropertyOptions.IsDefaultCollection)]
		public FormsAuthenticationUserCollection Users {
			get { return (FormsAuthenticationUserCollection) base[usersProp]; }
		}

		protected override ConfigurationPropertyCollection Properties {
			get { return properties; }
		}
		
	}
}

#endif

==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/System.Web/System.Web.Configuration_2.0/FormsAuthenticationCredentials.cs <==
//
// System.Web.Configuration.FormsAuthenticationCredentials
//
// Authors:
//	Chris Toshok (toshok@ximian.com)
//
// (C) 2005 Novell, Inc (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System.Configuration;
using System.ComponentModel;

namespace System.Web.Configuration
{
	public sealed class FormsAuthenticationCredentials: ConfigurationElement
	{
		static ConfigurationPropertyCollection properties;
		static ConfigurationProperty passwordFormatProp;
		static ConfigurationProperty usersProp;

		static FormsAuthenticationCredentials ()
		{
			passwordFormatProp = new ConfigurationProperty ("passwordFormat", typeof (FormsAuthPasswordFormat), FormsAuthPasswordFormat.SHA1,
									new GenericEnumConverter (typeof (FormsAuthPasswordFormat)), PropertyHelper.DefaultValidator,
									ConfigurationPropertyOptions.None);
			usersProp = new ConfigurationProperty ("", typeof (FormsAuthenticationUserCollection), null,
							       null, PropertyHelper.DefaultValidator,
							       ConfigurationPropertyOptions.IsDefaultCollection);

			properties = new ConfigurationPropertyCollection ();
			properties.Add (passwordFormatProp);
			properties.Add (usersProp);
		}

		public FormsAuthenticationCredentials ()
		{
		}

		[ConfigurationProperty ("passwordFormat", DefaultValue = "SHA1")]
		public FormsAuthPasswordFormat PasswordFormat {
			get { return (FormsAuthPasswordFormat) base[passwordFormatProp]; }
			set { base[passwordFormatProp] = value; }
		}

		[ConfigurationProperty ("", Options = ConfigurationPropertyOptions.IsDefaultCollection)]
		public FormsAuthenticationUserCollection Users {
			get { return (FormsAuthenticationUserCollection) base[usersProp]; }
		}

		protected internal override ConfigurationPropertyCollection Properties {
			get { return properties; }
		}
		
	}
}

#endif
